@@ -106,7 +106,7 @@ class Stellar:
             steps += list(self.split_utils(cohort_tbl_nm = f'{self.group}_cohort', ER_tbl_nm = f'{self.group}_er_eligible', IP_tbl_nm = f'{self.group}_ip_all'))
 
             #----------------These steps are all to get follow-up rates---------------------------------
-            steps.append(self.unique_er_discharges(input_tbl_nm = ER_tbl_nm, output_tbl_nm = f'{self.group}_er_unique')) # get follow-ups for ALL ED visits so can include gap closed flag on final table
+            steps.append(self.unique_er_discharges(input_tbl_nm = f'{self.group}_er_eligible', output_tbl_nm = f'{self.group}_er_unique')) # get follow-ups for ALL ED visits so can include gap closed flag on final table
             steps.append(self.mbi_to_pty_lookup(input_tbl_nm = f'{self.group}_er_unique', output_tbl_nm = f'{self.group}_er_lookup'))
             steps.append(self.claims_after_discharge(input_tbl_nm = f'{self.group}_er_lookup', output_tbl_nm = f'{self.group}_er_clms_after'))
             steps.append(self.ed_follow_ups(discharge_tbl = f'{self.group}_er_unique',
@@ -127,7 +127,7 @@ class Stellar:
             
         return steps
     
-    def build_cohort(self, steps = None, pre_ER_steps = None, post_ER_steps = None):
+    def build_cohort(self, steps = None):
         '''
         
 
@@ -451,7 +451,7 @@ class Stellar:
                     UDW ADJ CLMS 
                     -------------*/
                     
-                    SELECT DISTINCT b.mbr_pty_id, b.proc_dt AS er_discharge
+                    SELECT DISTINCT b.mbr_pty_id, b.srvc_strt_dt AS er_discharge
                     
                     FROM UDWBASESECUREVIEW1.ADJD_MCE_SRVC_MAIN_F b
                     
@@ -460,8 +460,9 @@ class Stellar:
                     AND b.orig_src_sys_cd = c.orig_src_sys_cd
                     
                     
-                    WHERE b.proc_dt BETWEEN '2021-11-04' AND ADD_MONTHS(CURRENT_DATE(), -1) 
-                    AND (b.adjd_plsrv_cd = '23' OR b.proc_cd in ('99283', 'B1001','G9752','S9960')) --ER POS or ER procedure code
+                    WHERE b.proc_dt BETWEEN '2021-10-01' AND ADD_MONTHS(CURRENT_DATE(), -1)
+                    AND b.srvc_strt_dt BETWEEN '2021-11-04' AND ADD_MONTHS(CURRENT_DATE(), -1)
+                    AND (b.adjd_plsrv_cd = '23') -- OR b.proc_cd in ('99283', 'B1001','G9752','S9960')) --ER POS or ER procedure code
                     AND b.orig_src_sys_cd IN ('COS', 'NIC', 'CSP', 'APF', 'NDB', 'FRV', 'OXF') --MA/Medicaid only
                     AND b.mbr_pty_id IS NOT NULL
                         
@@ -480,9 +481,18 @@ class Stellar:
                     
                     
                     WHERE c.clm_srvc_strt_dt BETWEEN '2021-11-04' AND ADD_MONTHS(CURRENT_DATE(), -1) 
-                    AND (c.plsrv_cd = '23' OR c.bil_proc_cd IN ('99283', 'B1001','G9752','S9960')) --same date for both
+                    AND (c.plsrv_cd = '23') --OR c.bil_proc_cd IN ('99283', 'B1001','G9752','S9960')) --same date for both
                     AND b.orig_src_sys_cd IN ('COS', 'NIC', 'CSP', 'APF', 'NDB', 'FRV', 'OXF') --MA/Medicaid only
                     AND b.mbr_pty_id IS NOT NULL
+                    and b.udw_med_clm_id NOT IN (SELECT DISTINCT b.udw_med_clm_id
+                                                 FROM UDWBASESECUREVIEW1.ADJD_MCE b
+                                                             
+                                                 LEFT JOIN UDWBASESECUREVIEW1.ADJD_MCE_SRVC_MAIN_F c
+                                                 ON b.udw_med_clm_id = c.udw_med_clm_id
+                                                             
+                                                WHERE b.orig_src_sys_cd in ('COS', 'NIC', 'CSP', 'APF', 'NDB', 'FRV', 'OXF') 
+                                                AND b.proc_dt BETWEEN '2021-10-01' AND ADD_MONTHS(CURRENT_DATE(), -1)
+                                                AND c.srvc_strt_dt BETWEEN '2021-11-04' AND ADD_MONTHS(CURRENT_DATE(), -1))
                     )
                     WITH DATA
                     ON COMMIT PRESERVE ROWS;
@@ -1052,6 +1062,10 @@ class Stellar:
         '99408', '99409', 'G0396', 'G0397', 'G0443', 'H0001', 'H0005', 'H0007', 'H0015', 'H0016', 'H0022', 'H0047', 
         'H0050', 'H2035', 'H2036', 'T1006', 'T1012', '0906', '0944', '0945', '98969', '98970', '98971', '98972', '99421', '99422', '99423', '99444', '99457', 'G0071', 'G2010', 'G2012', 'G2061', 'G2062', 'G2063'
         )
+        AND c.udw_med_clm_id NOT IN (SELECT DISTINCT udw_med_clm_id
+                                     FROM UDWBASESECUREVIEW1.ADJD_MCE
+                                     WHERE orig_src_sys_cd in ('COS', 'NIC', 'CSP', 'APF', 'NDB', 'FRV', 'OXF')
+                                     AND proc_dt >= ADD_MONTHS(CURRENT_DATE(), -4))
 
         UNION
         
